==> layout_form_builder-1.0.43-dev.1.tar.gz: lib/datalayer/bean/eform_cache.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder_ing/app_colors.dart';
import 'package:flutter_form_builder_ing/flutter_form_builder_ing.dart';
import 'package:layout_form_builder/datalayer/constant/eform_properties.dart';
import 'package:nui_form/component/nuif_text.dart';
import '../../eform_layout_renderer.dart';
import '../../util.dart';
import 'package:intl/intl.dart';

class EFormCache{
  EFormCache._builder();
  static Map<String, GlobalKey<FormBuilderState>> _allFormKeys = Map<String, GlobalKey<FormBuilderState>>();

  static NUIFTextStyle? getTextStyle(){
    return EFormLayoutRenderer.initialized ? EFormLayoutRenderer.instance.textStyle : null;
  }

  static InputDecoration getInputDecoration({String? label: "", String? hint: "", Widget? suffix}){
    final textStyle = EFormLayoutRenderer.initialized ? EFormLayoutRenderer.instance.textStyle : null;
    final inputDecoration = InputDecoration(
      isDense: true,
      errorBorder: textStyle?.errorBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.FormErrorRed), borderRadius: BorderRadius.circular(6)),
      border: textStyle?.border ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      enabledBorder: textStyle?.enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      disabledBorder: textStyle?.enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      focusedBorder: textStyle?.focusedBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.AccentBright), borderRadius: BorderRadius.circular(6)),
      labelStyle: textStyle?.labelStyle,
      helperStyle: textStyle?.helperStyle,
      alignLabelWithHint: true,
      errorStyle: textStyle?.errorLabelStyle,
      hintStyle: textStyle?.hintStyle,
      labelText: label ?? "",
      hintText: hint ?? "",
      suffixIcon: suffix
    );

    return inputDecoration;
  }

  static String? getFormFieldPropString(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, String? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    return prop?.toString() ?? defaultValue;
  }

  static double? getFormFieldPropDouble(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, double? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return double.parse(prop);
    }
    return prop ?? defaultValue;
  }

  static DateTime? getFormFieldPropDateTime(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, DateTime? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return DateFormat("d/MM/yyyy").parse(prop);
    }
    return prop ?? defaultValue;
  }

  static bool getFormFieldPropBool(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, bool? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return prop.toLowerCase() == "true";
    }
    return prop ?? defaultValue ?? false;
  }

  static int? getFormFieldPropInt(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, int? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return int.parse(prop);
    }
    return prop ?? defaultValue;
  }

  static Color? getFormFieldPropColor(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, Color? defaultValue}){
    try{
      final colorHex = getFormFieldPropString(context, fp, name);
      return colorHex != null ? HexColor.fromHex(colorHex) : defaultValue;
    }catch(e){
      return defaultValue;
    }
  }

  static String? fieldString(Map<String, dynamic> fp, String name, {String? defaultValue}){
    final prop = fp[name];
    return prop?.toString() ?? defaultValue;
  }

  static dynamic fieldDynamic(Map<String, dynamic> fp, String name, {dynamic defaultValue}){
    final prop = fp[name];
    return prop ?? defaultValue;
  }

  static double? fieldDouble(Map<String, dynamic> fp, String name, {double? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      try {
        return double.parse(prop);
      }catch(e){
        return defaultValue;
      }
    }
    return prop ?? defaultValue;
  }

  static bool fieldBool(Map<String, dynamic> fp, String name, {bool? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      return prop.toLowerCase() == "true";
    }
    return prop ?? defaultValue ?? false;
  }

  static int? fieldInt(Map<String, dynamic> fp, String name, {int? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      try {
        return int.parse(prop);
      }catch(e){
        return defaultValue;
      }
    }
    return prop ?? defaultValue;
  }

  static Color? fieldColor(Map<String, dynamic> fp, String name, {Color? defaultValue}){
    final prop = fp[name];
    try{
      final colorHex = prop;
      return colorHex != null ? HexColor.fromHex(colorHex) : defaultValue;
    }catch(e){
      return defaultValue;
    }
  }

  static dynamic getFormFieldPropValue(BuildContext context, Map<String, dynamic> fp, String name, bool fromValidator) {
    // Map<String, dynamic>? widgetChgProps = context
    //     .watch<WidgetPropChangeNotifier>()
    //     .props[fp[EFormProperties.PROP_INPUT_ID]];

    Map<String, dynamic>? widgetChgProps;

    bool widgetChgPropsIsNull = false;
    if (widgetChgProps == null) {
      widgetChgPropsIsNull = true;
      widgetChgProps = fp;
    }

    if (fromValidator) {
      if (widgetChgProps.containsKey(EFormProperties.PROP_VALIDATORS)) {
        if (widgetChgProps[EFormProperties.PROP_VALIDATORS][name] != null) {
          return widgetChgProps[EFormProperties.PROP_VALIDATORS][name];
        }
      }
    } else {
      if (widgetChgProps[name] != null) {
        return widgetChgProps[name];
      }
    }

    if (!widgetChgPropsIsNull) {
      if (fromValidator) {
        if (fp.containsKey(EFormProperties.PROP_VALIDATORS)) {
          if (fp[EFormProperties.PROP_VALIDATORS][name] != null) {
            return fp[EFormProperties.PROP_VALIDATORS][name];
          }
        }
      } else {
        if (fp[name] != null) {
          return fp[name];
        }
      }
    }

    return null;
  }

  static FormBuilderFieldState? lookupFormField(Map<String, dynamic> mapFromParser) {
    return _allFormKeys[mapFromParser[EFormProperties.PROP_FORM_ID]]?.currentState?.fields[mapFromParser[EFormProperties.PROP_INPUT_ID]];
  }

  static Map<String, dynamic>? getFormValues(String formKey) {
    final key = _allFormKeys[formKey];
    if (key != null) {
      if (key.currentState != null) {
        final st = key.currentState!;
        st.save();
        if (st.validate()) {
          return st.value;
        }
      }
    }
    return null;
  }

  static void setFormFieldValue(Map<String, dynamic> mapFromParser, dynamic value) {
    lookupFormField(mapFromParser)?.didChange(value);
  }

  static void setFormFieldValueWithInputId(String inputId, String formId, dynamic value) {
    _allFormKeys[formId]?.currentState?.fields[inputId]?.didChange(value);
  }

  static dynamic getFormFieldInitValue(Map<String, dynamic> mapFromParser) {
    lookupFormField(mapFromParser)?.initialValue;
  }

  static dynamic getFormFieldEditedValue(Map<String, dynamic> mapFromParser) {
    lookupFormField(mapFromParser)?.value;
  }

  static GlobalKey<FormBuilderState>? getFormKey(String id){
    final key = _allFormKeys[id];
    if(key != null) return key;

    final newKey = GlobalKey<FormBuilderState>();
    _allFormKeys[id] = newKey;
    return newKey;
  }
}

==> layout_form_builder-1.0.46-dev.1.tar.gz: lib/datalayer/bean/eform_cache.dart <==
import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';
import 'package:flutter_form_builder_ing/app_colors.dart';
import 'package:flutter_form_builder_ing/flutter_form_builder_ing.dart';
import 'package:layout_form_builder/datalayer/constant/eform_properties.dart';
import 'package:nui_form/component/nuif_text.dart';
import '../../eform_layout_renderer.dart';
import '../../util.dart';
import 'package:intl/intl.dart';

class EFormCache{
  EFormCache._builder();
  static Map<String, GlobalKey<FormBuilderState>> _allFormKeys = Map<String, GlobalKey<FormBuilderState>>();

  static NUIFTextStyle? getTextStyle(){
    return EFormLayoutRenderer.initialized ? EFormLayoutRenderer.instance.textStyle : null;
  }

  static InputDecoration getInputDecoration({String? label: "", String? hint: "", Widget? suffix}){
    final textStyle = EFormLayoutRenderer.initialized ? EFormLayoutRenderer.instance.textStyle : null;
    final inputDecoration = InputDecoration(
      isDense: true,
      errorBorder: textStyle?.errorBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.FormErrorRed), borderRadius: BorderRadius.circular(6)),
      border: textStyle?.border ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      enabledBorder: textStyle?.enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      disabledBorder: textStyle?.enabledBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.GrayLineLight), borderRadius: BorderRadius.circular(6)),
      focusedBorder: textStyle?.focusedBorder ?? OutlineInputBorder(borderSide: BorderSide(color: AppColors.AccentBright), borderRadius: BorderRadius.circular(6)),
      labelStyle: textStyle?.labelStyle,
      helperStyle: textStyle?.helperStyle,
      alignLabelWithHint: true,
      errorStyle: textStyle?.errorLabelStyle,
      hintStyle: textStyle?.hintStyle,
      labelText: label ?? "",
      hintText: hint ?? "",
      suffixIcon: suffix
    );

    return inputDecoration;
  }

  static String? getFormFieldPropString(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, String? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    return prop?.toString() ?? defaultValue;
  }

  static double? getFormFieldPropDouble(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, double? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return double.parse(prop);
    }
    return prop ?? defaultValue;
  }

  static DateTime? getFormFieldPropDateTime(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, DateTime? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return DateFormat("dd MMM yyyy").parse(prop);
    }
    return prop ?? defaultValue;
  }

  static bool getFormFieldPropBool(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, bool? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return prop.toLowerCase() == "true";
    }
    return prop ?? defaultValue ?? false;
  }

  static int? getFormFieldPropInt(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, int? defaultValue}){
    final prop = getFormFieldPropValue(context, fp, name, fromValidator);
    if(prop != null && prop is String){
      return int.parse(prop);
    }
    return prop ?? defaultValue;
  }

  static Color? getFormFieldPropColor(BuildContext context, Map<String, dynamic> fp, String name, {bool fromValidator: false, Color? defaultValue}){
    try{
      final colorHex = getFormFieldPropString(context, fp, name);
      return colorHex != null ? HexColor.fromHex(colorHex) : defaultValue;
    }catch(e){
      return defaultValue;
    }
  }

  static String? fieldString(Map<String, dynamic> fp, String name, {String? defaultValue}){
    final prop = fp[name];
    return prop?.toString() ?? defaultValue;
  }

  static dynamic fieldDynamic(Map<String, dynamic> fp, String name, {dynamic defaultValue}){
    final prop = fp[name];
    return prop ?? defaultValue;
  }

  static double? fieldDouble(Map<String, dynamic> fp, String name, {double? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      try {
        return double.parse(prop);
      }catch(e){
        return defaultValue;
      }
    }
    return prop ?? defaultValue;
  }

  static bool fieldBool(Map<String, dynamic> fp, String name, {bool? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      return prop.toLowerCase() == "true";
    }
    return prop ?? defaultValue ?? false;
  }

  static int? fieldInt(Map<String, dynamic> fp, String name, {int? defaultValue}){
    final prop = fp[name];
    if(prop != null && prop is String){
      try {
        return int.parse(prop);
      }catch(e){
        return defaultValue;
      }
    }
    return prop ?? defaultValue;
  }

  static Color? fieldColor(Map<String, dynamic> fp, String name, {Color? defaultValue}){
    final prop = fp[name];
    try{
      final colorHex = prop;
      return colorHex != null ? HexColor.fromHex(colorHex) : defaultValue;
    }catch(e){
      return defaultValue;
    }
  }

  static dynamic getFormFieldPropValue(BuildContext context, Map<String, dynamic> fp, String name, bool fromValidator) {
    // Map<String, dynamic>? widgetChgProps = context
    //     .watch<WidgetPropChangeNotifier>()
    //     .props[fp[EFormProperties.PROP_INPUT_ID]];

    Map<String, dynamic>? widgetChgProps;

    bool widgetChgPropsIsNull = false;
    if (widgetChgProps == null) {
      widgetChgPropsIsNull = true;
      widgetChgProps = fp;
    }

    if (fromValidator) {
      if (widgetChgProps.containsKey(EFormProperties.PROP_VALIDATORS)) {
        if (widgetChgProps[EFormProperties.PROP_VALIDATORS][name] != null) {
          return widgetChgProps[EFormProperties.PROP_VALIDATORS][name];
        }
      }
    } else {
      if (widgetChgProps[name] != null) {
        return widgetChgProps[name];
      }
    }

    if (!widgetChgPropsIsNull) {
      if (fromValidator) {
        if (fp.containsKey(EFormProperties.PROP_VALIDATORS)) {
          if (fp[EFormProperties.PROP_VALIDATORS][name] != null) {
            return fp[EFormProperties.PROP_VALIDATORS][name];
          }
        }
      } else {
        if (fp[name] != null) {
          return fp[name];
        }
      }
    }

    return null;
  }

  static FormBuilderFieldState? lookupFormField(Map<String, dynamic> mapFromParser) {
    return _allFormKeys[mapFromParser[EFormProperties.PROP_FORM_ID]]?.currentState?.fields[mapFromParser[EFormProperties.PROP_INPUT_ID]];
  }

  static Map<String, dynamic>? getFormValues(String formKey) {
    final key = _allFormKeys[formKey];
    if (key != null) {
      if (key.currentState != null) {
        final st = key.currentState!;
        st.save();
        if (st.validate()) {
          return st.value;
        }
      }
    }
    return null;
  }

  static void setFormFieldValue(Map<String, dynamic> mapFromParser, dynamic value) {
    lookupFormField(mapFromParser)?.didChange(value);
  }

  static void setFormFieldValueWithInputId(String inputId, String formId, dynamic value) {
    _allFormKeys[formId]?.currentState?.fields[inputId]?.didChange(value);
  }

  static dynamic getFormFieldInitValue(Map<String, dynamic> mapFromParser) {
    lookupFormField(mapFromParser)?.initialValue;
  }

  static dynamic getFormFieldEditedValue(Map<String, dynamic> mapFromParser) {
    lookupFormField(mapFromParser)?.value;
  }

  static GlobalKey<FormBuilderState>? getFormKey(String id){
    final key = _allFormKeys[id];
    if(key != null) return key;

    final newKey = GlobalKey<FormBuilderState>();
    _allFormKeys[id] = newKey;
    return newKey;
  }
}
